[GHC] #5631: Compilation slowdown from 7.0.x to 7.2.x

GHC cvs-ghc at haskell.org
Tue Nov 22 16:28:43 CET 2011


#5631: Compilation slowdown from 7.0.x to 7.2.x
---------------------------------+------------------------------------------
    Reporter:  bjpop             |        Owner:  simonpj                     
        Type:  bug               |       Status:  new                         
    Priority:  highest           |    Milestone:  7.4.1                       
   Component:  Compiler          |      Version:  7.2.1                       
    Keywords:                    |     Testcase:                              
   Blockedby:                    |   Difficulty:                              
          Os:  Unknown/Multiple  |     Blocking:                              
Architecture:  Unknown/Multiple  |      Failure:  Compile-time performance bug
---------------------------------+------------------------------------------

Comment(by marlowsd@…):

 commit ed043776f3363b2b9e56f1e9836a250f43c28d26
 {{{
 Author: Simon Marlow <marlowsd at gmail.com>
 Date:   Tue Nov 22 14:09:05 2011 +0000

     uType_defer: only call mkErrInfo if -ddump-tc-trace is on (#5631)

     Profiling shows we're wasting a lot of time calling mkErrInfo and
     tidying the context, work that is wasted if we're not tracing.

     There is more to this compilation performance regression than this,
     but this is one bug.

  compiler/typecheck/TcUnify.lhs |   13 +++++++++----
  1 files changed, 9 insertions(+), 4 deletions(-)
 }}}

-- 
Ticket URL: <http://hackage.haskell.org/trac/ghc/ticket/5631#comment:6>
GHC <http://www.haskell.org/ghc/>
The Glasgow Haskell Compiler



More information about the Glasgow-haskell-bugs mailing list